Common Errors
=============

ValueError: <boa.network.NetworkEnv object at 0xXXXXXXXXX>.eoa not defined!
----------------------------------------------------------------------------

This is the most common error you'll encounter, and it means you'll need to add an account to your ``moccasin.toml`` file. You can do this by following the :doc:`wallet <core_concepts/wallet>` guide.